pub fn spawn<I, S>(args: I) -> Result<i32>Expand description
Run bsdkrun <args> inheriting the parent’s stdio (interactive).
Blocks until the child exits and returns its exit code. Used by
crate::Sandbox::shell.
pub fn spawn<I, S>(args: I) -> Result<i32>Run bsdkrun <args> inheriting the parent’s stdio (interactive).
Blocks until the child exits and returns its exit code. Used by
crate::Sandbox::shell.