pub struct RunBsdBuilder { /* private fields */ }Expand description
A runBsd mutation being assembled — see Client::run_bsd.
Implementations
Sourceimpl RunBsdBuilder
impl RunBsdBuilder
Sourcepub fn port(self, forward: impl Into<String>) -> Self
pub fn port(self, forward: impl Into<String>) -> Self
Add a host->guest TCP port forward, "HOST:GUEST".
Sourcepub fn forward(self, host: u16, guest: u16) -> Self
pub fn forward(self, host: u16, guest: u16) -> Self
Add a port forward from numbers instead of a string.
Sourcepub fn volume(self, name: impl Into<String>) -> Self
pub fn volume(self, name: impl Into<String>) -> Self
Use a persistent CoW volume as the root disk.
Sourcepub fn attach_disk(self, disk: impl Into<String>) -> Self
pub fn attach_disk(self, disk: impl Into<String>) -> Self
Attach an extra raw disk, "PATH" or "PATH:ro" (repeatable).
Sourcepub fn repo(self, repo: impl Into<String>) -> Self
pub fn repo(self, repo: impl Into<String>) -> Self
Clone a git repo into the guest before running.