pub struct RunLinuxBuilder { /* private fields */ }Expand description
A runLinux mutation being assembled — see Client::run_linux.
Implementations
Sourceimpl RunLinuxBuilder
impl RunLinuxBuilder
Sourcepub fn port(self, forward: impl Into<String>) -> Self
pub fn port(self, forward: impl Into<String>) -> Self
Add a host->guest TCP port forward, "HOST:GUEST".
Sourcepub fn forward(self, host: u16, guest: u16) -> Self
pub fn forward(self, host: u16, guest: u16) -> Self
Add a port forward from numbers instead of a string.
Sourcepub fn volume(self, name: impl Into<String>) -> Self
pub fn volume(self, name: impl Into<String>) -> Self
Use a persistent CoW volume as the rootfs.
Sourcepub fn mount(self, mount: impl Into<String>) -> Self
pub fn mount(self, mount: impl Into<String>) -> Self
Share a host directory into the guest, "HOST:GUEST" (repeatable).
Sourcepub fn env(self, key: impl Into<String>, value: impl Into<String>) -> Self
pub fn env(self, key: impl Into<String>, value: impl Into<String>) -> Self
Set a guest environment variable.
Sourcepub fn entrypoint(self, entrypoint: impl Into<String>) -> Self
pub fn entrypoint(self, entrypoint: impl Into<String>) -> Self
Override the image entrypoint.
Sourcepub fn kernel_version(self, version: impl Into<String>) -> Self
pub fn kernel_version(self, version: impl Into<String>) -> Self
Kernel version to fetch.
Sourcepub fn repo(self, repo: impl Into<String>) -> Self
pub fn repo(self, repo: impl Into<String>) -> Self
Clone a git repo into the guest before running.